import { useRef, useState, useEffect } from 'react';

function useClickOutside(callback) {
    var container = useRef(null);
    var _a = useState(false), isTouchEvent = _a[0], setTouchEvent = _a[1];
    var eventType = isTouchEvent ? 'touchend' : 'click';
    function handleEvent(e) {
        if (e.type === 'click' && isTouchEvent) {
            return;
        } // prettier-ignore
        if (container.current && e.target !== null) {
            if (!container.current.contains(e.target)) {
                callback(e);
            }
        }
    }
    useEffect(function () {
        document.addEventListener(eventType, handleEvent, true);
        return function () {
            document.removeEventListener(eventType, handleEvent, true);
        };
    });
    useEffect(function () {
        setTouchEvent('ontouchstart' in document.documentElement);
    }, []);
    return container;
}

export default useClickOutside;
//# sourceMappingURL=index.es.js.map
