'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');

function useClickOutside(callback) {
    var container = react.useRef(null);
    var _a = react.useState(false), isTouchEvent = _a[0], setTouchEvent = _a[1];
    var eventType = isTouchEvent ? 'touchend' : 'click';
    function handleEvent(e) {
        if (e.type === 'click' && isTouchEvent) {
            return;
        } // prettier-ignore
        if (container.current && e.target !== null) {
            if (!container.current.contains(e.target)) {
                callback(e);
            }
        }
    }
    react.useEffect(function () {
        document.addEventListener(eventType, handleEvent, true);
        return function () {
            document.removeEventListener(eventType, handleEvent, true);
        };
    });
    react.useEffect(function () {
        setTouchEvent('ontouchstart' in document.documentElement);
    }, []);
    return container;
}

exports.default = useClickOutside;
//# sourceMappingURL=index.js.map
